/*
**                      Softwarepraktikum iMaze
**                              1993/94
**                Joerg Czeranski    Hans-Ulrich Kiel
**
** Datei: server_netz.h
**
** Kommentar:
**  Definition der Prototypen fuer den Netzwerkteil im Server
*/


static char sccsid_server_netz[] = "@(#)server_netz.h	1.14 01 Oct 1994";


/* Prototypen fuer globale Netzwerk-Funktionen */

#ifdef __STDC__

int prolog_paket_senden(void *verbindung, int paket_laenge, void *paket);
int prolog_paket_empfangen(void *verbindung, int *paket_laenge,
	void **paket);
void spiel_paket_senden(void *verbindung, int paket_laenge, void *paket);
int spiel_paket_empfangen(int verbindungen_anz, void **verbindungen,
	int *paket_laenge, void **paket);
void verbindung_freigeben(void *verbindung);
void *verbindung_annehmen(void);
void verbindung_abbrechen(void *verbindung);
int verbindung_auf_spiel(void *session, void *verbindung);
void netzwerk_init(int *argc, char **argv);
void *session_starten(void);
void nachricht_senden(void *session, void *verbindung, int daten_laenge,
	void *daten);
int nachricht_empfangen(void *session, void **verbindung, int *daten_laenge,
	void **daten);
void nachricht_erwarten(void *session);
void *nachricht_oder_verbindung_erwarten(int anzsessions, void **sessions);

#else

int prolog_paket_senden();
int prolog_paket_empfangen();
void spiel_paket_senden();
int spiel_paket_empfangen();
void verbindung_freigeben();
void *verbindung_annehmen();
void verbindung_abbrechen();
int verbindung_auf_spiel();
void netzwerk_init();
void *session_starten();
void nachricht_senden();
int nachricht_empfangen();
void nachricht_erwarten();
void *nachricht_oder_verbindung_erwarten();

#endif
